pub struct RangeHandle {
pub tree_id: TreeId,
pub start_node: NodeId,
pub end_node: NodeId,
pub collapse_type: CollapseType,
}Expand description
Handle for referencing a range of nodes in another tree
Fields
tree_id: TreeIdSource tree containing the range
start_node: NodeIdFirst node in the range
end_node: NodeIdLast node in the range (must be descendant of start)
collapse_type: CollapseTypeHow to collapse this range
Implementations
Sourceimpl RangeHandle
impl RangeHandle
Sourcepub fn to_metadata(&self) -> Value
pub fn to_metadata(&self) -> Value
Convert to metadata Value that can be stored in arbor
Sourcepub fn from_metadata(metadata: &Value) -> Option<Self>
pub fn from_metadata(metadata: &Value) -> Option<Self>
Try to parse metadata as a RangeHandle