pub struct Tree {
pub id: TreeId,
pub root: NodeId,
pub nodes: HashMap<NodeId, Node>,
pub state: Option<ResourceState>,
pub refs: Option<ResourceRefs>,
pub scheduled_deletion_at: Option<i64>,
pub archived_at: Option<i64>,
pub created_at: i64,
pub updated_at: i64,
pub metadata: Option<Value>,
}Expand description
A conversation tree
Fields
id: TreeIdUnique identifier for this tree
root: NodeIdRoot node ID
nodes: HashMap<NodeId, Node>All nodes in the tree (NodeId -> Node)
state: Option<ResourceState>Reference counting state
refs: Option<ResourceRefs>Reference count information
scheduled_deletion_at: Option<i64>Scheduled deletion timestamp (Unix seconds)
archived_at: Option<i64>Archived timestamp (Unix seconds)
created_at: i64Creation timestamp (Unix seconds)
updated_at: i64Last modified timestamp (Unix seconds)
metadata: Option<Value>Optional tree-level metadata (name, description, etc.)
Implementations
Sourceimpl Tree
impl Tree
Sourcepub fn render(&self) -> String
pub fn render(&self) -> String
Render the tree as a text representation (handles shown as references)
Sourcepub async fn render_resolved<F, Fut>(&self, resolver: F) -> String
pub async fn render_resolved<F, Fut>(&self, resolver: F) -> String
Render the tree with resolved handle content
Takes a resolver function that converts handles to display strings. The resolver is called for each external node’s handle.
Example
ⓘ
let rendered = tree.render_resolved(|handle| async move {
plexus.resolve_handle(handle).await
.map(|stream| extract_content(stream))
.unwrap_or_else(|_| format!("[unresolved: {}]", handle))
}).await;Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Tree
impl<'de> Deserialize<'de> for Tree
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Tree> for TreeSkeleton
impl From<&Tree> for TreeSkeleton
Sourceimpl JsonSchema for Tree
impl JsonSchema for Tree
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl Eq for Tree
impl StructuralPartialEq for Tree