pub struct TreeSkeleton {
pub id: TreeId,
pub root: NodeId,
pub nodes: HashMap<NodeId, NodeSkeleton>,
pub state: Option<ResourceState>,
}Expand description
Lightweight tree structure
Fields
id: TreeIdroot: NodeIdnodes: HashMap<NodeId, NodeSkeleton>state: Option<ResourceState>Trait Implementations
Sourceimpl Clone for TreeSkeleton
impl Clone for TreeSkeleton
Sourcefn clone(&self) -> TreeSkeleton
fn clone(&self) -> TreeSkeleton
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TreeSkeleton
impl Debug for TreeSkeleton
Sourceimpl<'de> Deserialize<'de> for TreeSkeleton
impl<'de> Deserialize<'de> for TreeSkeleton
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Tree> for TreeSkeleton
impl From<&Tree> for TreeSkeleton
Sourceimpl JsonSchema for TreeSkeleton
impl JsonSchema for TreeSkeleton
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TreeSkeleton
impl PartialEq for TreeSkeleton
Sourceimpl Serialize for TreeSkeleton
impl Serialize for TreeSkeleton
impl Eq for TreeSkeleton
impl StructuralPartialEq for TreeSkeleton