pub enum BashMethod {
Execute {
command: String,
},
}Expand description
Auto-generated method enum for schema extraction
Variants
Implementations
Sourceimpl BashMethod
impl BashMethod
pub fn all_method_names() -> &'static [&'static str]
Sourceimpl BashMethod
impl BashMethod
Sourcepub fn method_schemas() -> Vec<MethodSchema>
pub fn method_schemas() -> Vec<MethodSchema>
Get per-method schema info including params, return types, and content hashes
Note: This method has O(1) schema lookup cost after first call due to caching.