pub struct ProcessInfo {
pub pid: u32,
pub cmdline: String,
}Expand description
A process found on the system
Fields
pid: u32cmdline: StringTrait Implementations
Sourceimpl Clone for ProcessInfo
impl Clone for ProcessInfo
Sourcefn clone(&self) -> ProcessInfo
fn clone(&self) -> ProcessInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProcessInfo
impl Debug for ProcessInfo
Sourceimpl<'de> Deserialize<'de> for ProcessInfo
impl<'de> Deserialize<'de> for ProcessInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProcessInfo
impl JsonSchema for ProcessInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProcessInfo
impl RefUnwindSafe for ProcessInfo
impl Send for ProcessInfo
impl Sync for ProcessInfo
impl Unpin for ProcessInfo
impl UnsafeUnpin for ProcessInfo
impl UnwindSafe for ProcessInfo