pub struct RunningNode {
pub graph_id: String,
pub node_id: String,
pub spec_type: String,
}Expand description
A running node found across all active graphs
Fields
graph_id: Stringnode_id: Stringspec_type: StringTrait Implementations
Sourceimpl Clone for RunningNode
impl Clone for RunningNode
Sourcefn clone(&self) -> RunningNode
fn clone(&self) -> RunningNode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RunningNode
impl Debug for RunningNode
Sourceimpl<'de> Deserialize<'de> for RunningNode
impl<'de> Deserialize<'de> for RunningNode
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RunningNode
impl JsonSchema for RunningNode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RunningNode
impl RefUnwindSafe for RunningNode
impl Send for RunningNode
impl Sync for RunningNode
impl Unpin for RunningNode
impl UnsafeUnpin for RunningNode
impl UnwindSafe for RunningNode