pub enum ConeMethod {
Create {
name: String,
model_id: String,
system_prompt: Option<String>,
metadata: Option<Value>,
},
Get {
identifier: ConeIdentifier,
},
List,
Delete {
identifier: ConeIdentifier,
},
Chat {
identifier: ConeIdentifier,
prompt: String,
ephemeral: Option<bool>,
},
SetHead {
identifier: ConeIdentifier,
node_id: NodeId,
},
Registry,
}Expand description
Auto-generated method enum for schema extraction
Variants
Create
Create a new cone (LLM agent with persistent conversation context)
Get
Get cone configuration by name or ID
Fields

identifier: ConeIdentifierList
List all cones
Delete
Delete a cone (associated tree is preserved)
Fields

identifier: ConeIdentifierChat
Chat with a cone - appends prompt to context, calls LLM, advances head
SetHead
Move cone’s canonical head to a different node in the tree
Registry
Get available LLM services and models
Implementations
Sourceimpl ConeMethod
impl ConeMethod
pub fn all_method_names() -> &'static [&'static str]
Sourceimpl ConeMethod
impl ConeMethod
Sourcepub fn method_schemas() -> Vec<MethodSchema>
pub fn method_schemas() -> Vec<MethodSchema>
Get per-method schema info including params, return types, and content hashes
Note: This method has O(1) schema lookup cost after first call due to caching.