pub struct ConeInfo {
pub id: ConeId,
pub name: String,
pub model_id: String,
pub head: Position,
pub created_at: i64,
}Expand description
Lightweight cone info (for listing)
Fields
id: ConeIdname: Stringmodel_id: Stringhead: Positioncreated_at: i64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ConeInfo
impl<'de> Deserialize<'de> for ConeInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&ConeConfig> for ConeInfo
impl From<&ConeConfig> for ConeInfo
Sourcefn from(config: &ConeConfig) -> Self
fn from(config: &ConeConfig) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ConeInfo
impl JsonSchema for ConeInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConeInfo
impl RefUnwindSafe for ConeInfo
impl Send for ConeInfo
impl Sync for ConeInfo
impl Unpin for ConeInfo
impl UnsafeUnpin for ConeInfo
impl UnwindSafe for ConeInfo