pub struct LatticeGraph {
pub id: GraphId,
pub metadata: Value,
pub status: GraphStatus,
pub created_at: i64,
pub node_count: usize,
pub edge_count: usize,
pub parent_graph_id: Option<String>,
}Fields
id: GraphIdmetadata: Valuestatus: GraphStatuscreated_at: i64node_count: usizeedge_count: usizeparent_graph_id: Option<String>Trait Implementations
Sourceimpl Clone for LatticeGraph
impl Clone for LatticeGraph
Sourcefn clone(&self) -> LatticeGraph
fn clone(&self) -> LatticeGraph
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LatticeGraph
impl Debug for LatticeGraph
Sourceimpl<'de> Deserialize<'de> for LatticeGraph
impl<'de> Deserialize<'de> for LatticeGraph
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LatticeGraph
impl JsonSchema for LatticeGraph
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LatticeGraph
impl RefUnwindSafe for LatticeGraph
impl Send for LatticeGraph
impl Sync for LatticeGraph
impl Unpin for LatticeGraph
impl UnsafeUnpin for LatticeGraph
impl UnwindSafe for LatticeGraph