pub struct ResolvedToken {
pub color: TokenColor,
pub data: Option<Value>,
}Expand description
A token with its payload fully resolved to an inline Value. Handles have been fetched from their backing store server-side.
Fields
color: TokenColordata: Option<Value>Trait Implementations
Sourceimpl Clone for ResolvedToken
impl Clone for ResolvedToken
Sourcefn clone(&self) -> ResolvedToken
fn clone(&self) -> ResolvedToken
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedToken
impl Debug for ResolvedToken
Sourceimpl<'de> Deserialize<'de> for ResolvedToken
impl<'de> Deserialize<'de> for ResolvedToken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ResolvedToken
impl JsonSchema for ResolvedToken
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResolvedToken
impl RefUnwindSafe for ResolvedToken
impl Send for ResolvedToken
impl Sync for ResolvedToken
impl Unpin for ResolvedToken
impl UnsafeUnpin for ResolvedToken
impl UnwindSafe for ResolvedToken