pub struct Mustache { /* private fields */ }Expand description
Mustache activation - renders values using mustache templates
Implementations
Sourceimpl Mustache
impl Mustache
Sourcepub async fn new(config: MustacheStorageConfig) -> Result<Self, String>
pub async fn new(config: MustacheStorageConfig) -> Result<Self, String>
Create a new Mustache activation with the given storage config
Sourcepub async fn with_defaults() -> Result<Self, String>
pub async fn with_defaults() -> Result<Self, String>
Create with default configuration
Sourcepub fn storage(&self) -> &MustacheStorage
pub fn storage(&self) -> &MustacheStorage
Get access to the underlying storage
Sourcepub async fn register_template_direct(
&self,
plugin_id: Uuid,
method: &str,
name: &str,
template: &str,
) -> Result<(), String>
pub async fn register_template_direct( &self, plugin_id: Uuid, method: &str, name: &str, template: &str, ) -> Result<(), String>
Register a template directly (non-streaming, for initialization)
Use this method during plugin initialization to register default templates.
Unlike the RPC register_template method, this doesn’t return a stream.