pub enum ListMonitorTreesResult {
Ok {
trees: Vec<MonitorTreeInfo>,
},
}Expand description
Result of listing monitor trees
Variants
Ok
Fields

trees: Vec<MonitorTreeInfo>Trait Implementations
Sourceimpl Clone for ListMonitorTreesResult
impl Clone for ListMonitorTreesResult
Sourcefn clone(&self) -> ListMonitorTreesResult
fn clone(&self) -> ListMonitorTreesResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListMonitorTreesResult
impl Debug for ListMonitorTreesResult
Sourceimpl<'de> Deserialize<'de> for ListMonitorTreesResult
impl<'de> Deserialize<'de> for ListMonitorTreesResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListMonitorTreesResult
impl JsonSchema for ListMonitorTreesResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListMonitorTreesResult
impl RefUnwindSafe for ListMonitorTreesResult
impl Send for ListMonitorTreesResult
impl Sync for ListMonitorTreesResult
impl Unpin for ListMonitorTreesResult
impl UnsafeUnpin for ListMonitorTreesResult
impl UnwindSafe for ListMonitorTreesResult