pub struct AgentInfo {
pub agent_id: AgentId,
pub session_id: SessionId,
pub claudecode_session_id: String,
pub subtask: String,
pub state: AgentState,
pub is_primary: bool,
pub parent_agent_id: Option<AgentId>,
pub created_at: i64,
pub last_activity: i64,
pub completed_at: Option<i64>,
pub error_message: Option<String>,
}Expand description
Agent metadata and state
Fields
agent_id: AgentIdsession_id: SessionIdclaudecode_session_id: Stringsubtask: Stringstate: AgentStateis_primary: boolparent_agent_id: Option<AgentId>created_at: i64last_activity: i64completed_at: Option<i64>error_message: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AgentInfo
impl<'de> Deserialize<'de> for AgentInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentInfo
impl JsonSchema for AgentInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentInfo
impl RefUnwindSafe for AgentInfo
impl Send for AgentInfo
impl Sync for AgentInfo
impl Unpin for AgentInfo
impl UnsafeUnpin for AgentInfo
impl UnwindSafe for AgentInfo