pub struct ApprovalInfo {
pub approval_id: String,
pub session_id: String,
pub tool_name: String,
pub tool_use_id: String,
pub tool_input: Value,
pub created_at: String,
}Expand description
Information about a pending approval request
Fields
approval_id: Stringsession_id: Stringtool_name: Stringtool_use_id: Stringtool_input: Valuecreated_at: StringTrait Implementations
Sourceimpl Clone for ApprovalInfo
impl Clone for ApprovalInfo
Sourcefn clone(&self) -> ApprovalInfo
fn clone(&self) -> ApprovalInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ApprovalInfo
impl Debug for ApprovalInfo
Sourceimpl<'de> Deserialize<'de> for ApprovalInfo
impl<'de> Deserialize<'de> for ApprovalInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ApprovalInfo
impl JsonSchema for ApprovalInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ApprovalInfo
impl RefUnwindSafe for ApprovalInfo
impl Send for ApprovalInfo
impl Sync for ApprovalInfo
impl Unpin for ApprovalInfo
impl UnsafeUnpin for ApprovalInfo
impl UnwindSafe for ApprovalInfo