pub struct CheckStatusRequest {
pub session_id: SessionId,
}Expand description
Request to check status of a running session
Fields
session_id: SessionIdTrait Implementations
Sourceimpl Clone for CheckStatusRequest
impl Clone for CheckStatusRequest
Sourcefn clone(&self) -> CheckStatusRequest
fn clone(&self) -> CheckStatusRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckStatusRequest
impl Debug for CheckStatusRequest
Sourceimpl<'de> Deserialize<'de> for CheckStatusRequest
impl<'de> Deserialize<'de> for CheckStatusRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CheckStatusRequest
impl JsonSchema for CheckStatusRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CheckStatusRequest
impl RefUnwindSafe for CheckStatusRequest
impl Send for CheckStatusRequest
impl Sync for CheckStatusRequest
impl Unpin for CheckStatusRequest
impl UnsafeUnpin for CheckStatusRequest
impl UnwindSafe for CheckStatusRequest