pub struct GetAgentRequest {
pub agent_id: AgentId,
}Expand description
Request to get specific agent info
Fields
agent_id: AgentIdTrait Implementations
Sourceimpl Clone for GetAgentRequest
impl Clone for GetAgentRequest
Sourcefn clone(&self) -> GetAgentRequest
fn clone(&self) -> GetAgentRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetAgentRequest
impl Debug for GetAgentRequest
Sourceimpl<'de> Deserialize<'de> for GetAgentRequest
impl<'de> Deserialize<'de> for GetAgentRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GetAgentRequest
impl JsonSchema for GetAgentRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GetAgentRequest
impl RefUnwindSafe for GetAgentRequest
impl Send for GetAgentRequest
impl Sync for GetAgentRequest
impl Unpin for GetAgentRequest
impl UnsafeUnpin for GetAgentRequest
impl UnwindSafe for GetAgentRequest