pub struct ListApprovalsRequest {
pub session_id: SessionId,
}Expand description
Request to list pending approvals for a session
Fields
session_id: SessionIdTrait Implementations
Sourceimpl Clone for ListApprovalsRequest
impl Clone for ListApprovalsRequest
Sourcefn clone(&self) -> ListApprovalsRequest
fn clone(&self) -> ListApprovalsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListApprovalsRequest
impl Debug for ListApprovalsRequest
Sourceimpl<'de> Deserialize<'de> for ListApprovalsRequest
impl<'de> Deserialize<'de> for ListApprovalsRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListApprovalsRequest
impl JsonSchema for ListApprovalsRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListApprovalsRequest
impl RefUnwindSafe for ListApprovalsRequest
impl Send for ListApprovalsRequest
impl Sync for ListApprovalsRequest
impl Unpin for ListApprovalsRequest
impl UnsafeUnpin for ListApprovalsRequest
impl UnwindSafe for ListApprovalsRequest