pub struct MonitorTreeInfo {
pub tree_id: String,
pub session_id: String,
pub tree_path: String,
}Expand description
Information about a monitor tree
Fields
tree_id: Stringsession_id: Stringtree_path: StringTrait Implementations
Sourceimpl Clone for MonitorTreeInfo
impl Clone for MonitorTreeInfo
Sourcefn clone(&self) -> MonitorTreeInfo
fn clone(&self) -> MonitorTreeInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MonitorTreeInfo
impl Debug for MonitorTreeInfo
Sourceimpl<'de> Deserialize<'de> for MonitorTreeInfo
impl<'de> Deserialize<'de> for MonitorTreeInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MonitorTreeInfo
impl JsonSchema for MonitorTreeInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MonitorTreeInfo
impl RefUnwindSafe for MonitorTreeInfo
impl Send for MonitorTreeInfo
impl Sync for MonitorTreeInfo
impl Unpin for MonitorTreeInfo
impl UnsafeUnpin for MonitorTreeInfo
impl UnwindSafe for MonitorTreeInfo