pub struct OrchaNodeDef {
pub id: String,
pub spec: OrchaNodeSpec,
}Expand description
One node in an inline graph definition.
id is a caller-supplied stable label used in OrchaEdgeDef.
Fields
id: Stringspec: OrchaNodeSpecTrait Implementations
Sourceimpl Clone for OrchaNodeDef
impl Clone for OrchaNodeDef
Sourcefn clone(&self) -> OrchaNodeDef
fn clone(&self) -> OrchaNodeDef
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OrchaNodeDef
impl Debug for OrchaNodeDef
Sourceimpl<'de> Deserialize<'de> for OrchaNodeDef
impl<'de> Deserialize<'de> for OrchaNodeDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OrchaNodeDef
impl JsonSchema for OrchaNodeDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OrchaNodeDef
impl RefUnwindSafe for OrchaNodeDef
impl Send for OrchaNodeDef
impl Sync for OrchaNodeDef
impl Unpin for OrchaNodeDef
impl UnsafeUnpin for OrchaNodeDef
impl UnwindSafe for OrchaNodeDef