pub struct SubmitTaskRequest {
pub session_id: SessionId,
pub task: String,
}Expand description
Request to submit a task to a session
Fields
session_id: SessionIdtask: StringTrait Implementations
Sourceimpl Clone for SubmitTaskRequest
impl Clone for SubmitTaskRequest
Sourcefn clone(&self) -> SubmitTaskRequest
fn clone(&self) -> SubmitTaskRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubmitTaskRequest
impl Debug for SubmitTaskRequest
Sourceimpl<'de> Deserialize<'de> for SubmitTaskRequest
impl<'de> Deserialize<'de> for SubmitTaskRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SubmitTaskRequest
impl JsonSchema for SubmitTaskRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SubmitTaskRequest
impl RefUnwindSafe for SubmitTaskRequest
impl Send for SubmitTaskRequest
impl Sync for SubmitTaskRequest
impl Unpin for SubmitTaskRequest
impl UnsafeUnpin for SubmitTaskRequest
impl UnwindSafe for SubmitTaskRequest