Plexus RPC builder - constructs a fully configured DynamicHub instance
This module is used by both the main binary and examples.
Functions
- build_
plexus_ rpc - Build the Plexus RPC hub with registered activations
Plexus RPC builder - constructs a fully configured DynamicHub instance
This module is used by both the main binary and examples.