pub struct BidirWithFallback<Req, Resp>where
Req: Serialize + DeserializeOwned + Send + 'static,
Resp: Serialize + DeserializeOwned + Send + 'static,{ /* private fields */ }Expand description
Bidirectional channel with fallback when transport doesn’t support bidirectional
Wraps a BidirChannel and provides fallback values when bidirectional requests fail due to NotSupported error.
Implementations
Sourceimpl<Req, Resp> BidirWithFallback<Req, Resp>where
Req: Serialize + DeserializeOwned + Send + 'static,
Resp: Serialize + DeserializeOwned + Send + 'static,
impl<Req, Resp> BidirWithFallback<Req, Resp>where
Req: Serialize + DeserializeOwned + Send + 'static,
Resp: Serialize + DeserializeOwned + Send + 'static,
Sourcepub fn new(
channel: Arc<BidirChannel<Req, Resp>>,
fallback: impl Fn(&Req) -> Resp + Send + Sync + 'static,
) -> BidirWithFallback<Req, Resp>
pub fn new( channel: Arc<BidirChannel<Req, Resp>>, fallback: impl Fn(&Req) -> Resp + Send + Sync + 'static, ) -> BidirWithFallback<Req, Resp>
Create a new fallback wrapper with custom fallback function
Sourceimpl BidirWithFallback<StandardRequest, StandardResponse>
impl BidirWithFallback<StandardRequest, StandardResponse>
Sourcepub fn auto_confirm(
channel: Arc<BidirChannel<StandardRequest, StandardResponse>>,
) -> BidirWithFallback<StandardRequest, StandardResponse>
pub fn auto_confirm( channel: Arc<BidirChannel<StandardRequest, StandardResponse>>, ) -> BidirWithFallback<StandardRequest, StandardResponse>
Create fallback that auto-confirms all requests