Module streaming

Module streaming 

Streaming helpers for the caller-wraps architecture

These functions are used by the DynamicHub routing layer to wrap activation responses with metadata. Activations return typed domain events, and the caller uses these helpers to create PlexusStreamItems.

Functions

create_bidir_stream
Create a bidirectional channel and wrap a stream, merging Request items
done_stream
Create a done stream
error_stream
Create an error stream
error_stream_with_code
Create an error stream with error code
progress_stream
Create a progress stream
wrap_stream
Wrap a typed stream into PlexusStream with automatic Done event
wrap_stream_with_bidir
Wrap a typed stream with bidirectional support

Type Aliases

PlexusStream
Type alias for boxed stream of PlexusStreamItem