Activation

Trait Activation 

pub trait Activation:
    Send
    + Sync
    + 'static {
    type Methods: MethodEnumSchema;

    // Required methods
    fn namespace(&self) -> &str;
    fn version(&self) -> &str;
    fn methods(&self) -> Vec<&str>;
    fn call<'life0, 'life1, 'async_trait>(
        &'life0 self,
        method: &'life1 str,
        params: Value,
    ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait;
    fn into_rpc_methods(self) -> Methods
       where Self: Sized;

    // Provided methods
    fn description(&self) -> &str { ... }
    fn long_description(&self) -> Option<&str> { ... }
    fn method_help(&self, _method: &str) -> Option<String> { ... }
    fn plugin_id(&self) -> Uuid { ... }
    fn resolve_handle<'life0, 'life1, 'async_trait>(
        &'life0 self,
        _handle: &'life1 Handle,
    ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
       where 'life0: 'async_trait,
             'life1: 'async_trait,
             Self: 'async_trait { ... }
    fn plugin_schema(&self) -> PluginSchema { ... }
}

Required Associated Types

Required Methods

fn namespace(&self) -> &str

fn version(&self) -> &str

fn methods(&self) -> Vec<&str>

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

fn into_rpc_methods(self) -> Methods
where Self: Sized,

Provided Methods

fn description(&self) -> &str

Short description (max 15 words)

fn long_description(&self) -> Option<&str>

Long description (optional, for detailed documentation)

fn method_help(&self, _method: &str) -> Option<String>

fn plugin_id(&self) -> Uuid

Stable activation instance ID for handle routing By default generates a deterministic UUID from namespace+major_version Using major version only ensures handles survive minor/patch upgrades (semver)

fn resolve_handle<'life0, 'life1, 'async_trait>( &'life0 self, _handle: &'life1 Handle, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Self: 'async_trait,

fn plugin_schema(&self) -> PluginSchema

Return this activation’s schema (methods + optional children)

Implementations on Foreign Types

Source

impl Activation for AuthHub

Source

type Methods = AuthHubMethod

Source

fn namespace(&self) -> &str

Source

fn version(&self) -> &str

Source

fn description(&self) -> &str

Source

fn long_description(&self) -> Option<&str>

Source

fn methods(&self) -> Vec<&str>

Source

fn method_help(&self, method: &str) -> Option<String>

Source

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, AuthHub: 'async_trait,

Source

fn into_rpc_methods(self) -> Methods

Source

fn plugin_schema(&self) -> PluginSchema

Source

impl Activation for HyperforgeHub

Source

type Methods = HyperforgeHubMethod

Source

fn namespace(&self) -> &str

Source

fn version(&self) -> &str

Source

fn description(&self) -> &str

Source

fn long_description(&self) -> Option<&str>

Source

fn methods(&self) -> Vec<&str>

Source

fn method_help(&self, method: &str) -> Option<String>

Source

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, HyperforgeHub: 'async_trait,

Source

fn into_rpc_methods(self) -> Methods

Source

fn plugin_schema(&self) -> PluginSchema

Source

impl Activation for RepoHub

Source

type Methods = RepoHubMethod

Source

fn namespace(&self) -> &str

Source

fn version(&self) -> &str

Source

fn description(&self) -> &str

Source

fn long_description(&self) -> Option<&str>

Source

fn methods(&self) -> Vec<&str>

Source

fn method_help(&self, method: &str) -> Option<String>

Source

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, RepoHub: 'async_trait,

Source

fn into_rpc_methods(self) -> Methods

Source

fn plugin_schema(&self) -> PluginSchema

Source

impl Activation for WorkspaceHub

Source

type Methods = WorkspaceHubMethod

Source

fn namespace(&self) -> &str

Source

fn version(&self) -> &str

Source

fn description(&self) -> &str

Source

fn long_description(&self) -> Option<&str>

Source

fn methods(&self) -> Vec<&str>

Source

fn method_help(&self, method: &str) -> Option<String>

Source

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, WorkspaceHub: 'async_trait,

Source

fn into_rpc_methods(self) -> Methods

Source

fn plugin_schema(&self) -> PluginSchema

Source

impl Activation for Registry

Source

type Methods = RegistryMethod

Source

fn namespace(&self) -> &str

Source

fn version(&self) -> &str

Source

fn description(&self) -> &str

Source

fn long_description(&self) -> Option<&str>

Source

fn methods(&self) -> Vec<&str>

Source

fn method_help(&self, method: &str) -> Option<String>

Source

fn call<'life0, 'life1, 'async_trait>( &'life0 self, method: &'life1 str, params: Value, ) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = PlexusStreamItem> + Send>>, PlexusError>> + Send + 'async_trait>>
where 'life0: 'async_trait, 'life1: 'async_trait, Registry: 'async_trait,

Source

fn into_rpc_methods(self) -> Methods

Source

fn plugin_schema(&self) -> PluginSchema

Implementors

Source

impl Activation for Bash

Source

impl Activation for Changelog

Source

type Methods = ChangelogMethod

Source

impl Activation for ClaudeCodeLoopback

Source

type Methods = ClaudeCodeLoopbackMethod

Source

impl Activation for plexus_substrate::activations::echo::Echo

Source

type Methods = EchoMethod

Source

impl Activation for plexus_substrate::activations::health::Health

Activation trait implementation - unified interface for Plexus

Source

impl Activation for Interactive

Source

type Methods = InteractiveMethod

Source

impl Activation for Mustache

Source

type Methods = MustacheMethod

Source

impl Activation for Solar

Source

type Methods = SolarMethod

Source

impl Activation for plexus_core::activations::echo::activation::Echo

Source

type Methods = EchoMethod

Source

impl Activation for plexus_core::activations::health::activation::Health

Activation trait implementation - unified interface for Plexus

Source

impl Activation for DynamicHub

Source

impl<P: HubContext> Activation for Arbor<P>

Source

impl<P: HubContext> Activation for ClaudeCode<P>

Source

impl<P: HubContext> Activation for Cone<P>