Streaming helpers for the caller-wraps architecture
These functions are used by the DynamicHub routing layer to wrap activation responses with metadata. Activations return typed domain events, and the caller uses these helpers to create PlexusStreamItems.
Functions
- create_
bidir_ stream - Create a bidirectional channel and wrap a stream, merging Request items
- done_
stream - Create a done stream
- error_
stream - Create an error stream
- error_
stream_ with_ code - Create an error stream with error code
- progress_
stream - Create a progress stream
- wrap_
stream - Wrap a typed stream into PlexusStream with automatic Done event
- wrap_
stream_ with_ bidir - Wrap a typed stream with bidirectional support
Type Aliases
- Plexus
Stream - Type alias for boxed stream of PlexusStreamItem